@@ -20,10 +20,16 @@ package org.apache.skywalking.banyandb.v1.client;
 
 import io.grpc.stub.StreamObserver;
 import lombok.extern.slf4j.Slf4j;
+
+import org.apache.skywalking.banyandb.common.v1.BanyandbCommon;
 import org.apache.skywalking.banyandb.measure.v1.BanyandbMeasure;
 import org.apache.skywalking.banyandb.measure.v1.MeasureServiceGrpc;
+import org.apache.skywalking.banyandb.v1.client.grpc.exception.BanyanDBException;
 
 import javax.annotation.concurrent.ThreadSafe;
+
+import java.util.HashSet;
+import java.util.Set;
 import java.util.concurrent.CompletableFuture;
 
 /**
@@ -33,30 +39,50 @@ import java.util.concurrent.CompletableFuture;
 @ThreadSafe
 public class MeasureBulkWriteProcessor extends AbstractBulkWriteProcessor<BanyandbMeasure.WriteRequest,
         MeasureServiceGrpc.MeasureServiceStub> {
+    private final BanyanDBClient client;
+
     /**
      * Create the processor.
      *
-     * @param measureServiceStub stub for gRPC call.
-     * @param maxBulkSize        the max bulk size for the flush operation
-     * @param flushInterval      if given maxBulkSize is not reached in this period, the flush would be trigger
-     *                           automatically. Unit is second.
-     * @param concurrency        the number of concurrency would run for the flush max.
+     * @param client        the client
+     * @param maxBulkSize   the max bulk size for the flush operation
+     * @param flushInterval if given maxBulkSize is not reached in this period, the flush would be trigger
+     *                      automatically. Unit is second.
+     * @param concurrency   the number of concurrency would run for the flush max.
      */
     protected MeasureBulkWriteProcessor(
-            final MeasureServiceGrpc.MeasureServiceStub measureServiceStub,
+            final BanyanDBClient client,
             final int maxBulkSize,
             final int flushInterval,
             final int concurrency) {
-        super(measureServiceStub, "MeasureBulkWriteProcessor", maxBulkSize, flushInterval, concurrency);
+        super(client.getMeasureServiceStub(), "MeasureBulkWriteProcessor", maxBulkSize, flushInterval, concurrency);
+        this.client = client;
     }
 
     @Override
     protected StreamObserver<BanyandbMeasure.WriteRequest> buildStreamObserver(MeasureServiceGrpc.MeasureServiceStub stub,
                                                                                CompletableFuture<Void> batch) {
         return stub.write(new StreamObserver<BanyandbMeasure.WriteResponse>() {
+            private final Set<String> schemaExpired = new HashSet<>();
+
             @Override
             public void onNext(BanyandbMeasure.WriteResponse writeResponse) {
-
+                switch (writeResponse.getStatus()) {
+                    case STATUS_EXPIRED_SCHEMA:
+                        BanyandbCommon.Metadata metadata = writeResponse.getMetadata();
+                        String schemaKey = metadata.getGroup() + "." + metadata.getName();
+                        if (!schemaExpired.contains(schemaKey)) {
+                            log.warn("The schema {} is expired, trying update the schema...", schemaKey);
+                            try {
+                                client.findMeasure(metadata.getGroup(), metadata.getName());
+                                schemaExpired.add(schemaKey);
+                            } catch (BanyanDBException e) {
+                                throw new RuntimeException(e);
+                            }
+                        }
+                        break;
+                    default:
+                }
             }
 
             @Override
