@@ -86,17 +86,6 @@ public abstract class Value<T> {
         }
     }
 
-    public static class IDTagValue extends Value<String> implements Serializable<BanyandbModel.TagValue> {
-        private IDTagValue(String value) {
-            super(value);
-        }
-
-        @Override
-        public BanyandbModel.TagValue serialize() {
-            return BanyandbModel.TagValue.newBuilder().setId(BanyandbModel.ID.newBuilder().setValue(value)).build();
-        }
-    }
-
     /**
      * The value of an int64(Long) type tag.
      */
@@ -152,20 +141,16 @@ public abstract class Value<T> {
         return new StringTagValue(val);
     }
 
-    static Serializable<BanyandbModel.TagValue> idTagValue(String val) {
-        if (Strings.isNullOrEmpty(val)) {
-            throw new NullPointerException();
-        }
-        return new IDTagValue(val);
-    }
-
     /**
      * Construct a numeric tag
      *
      * @param val payload
      * @return Anonymous tag with numeric payload
      */
-    public static Serializable<BanyandbModel.TagValue> longTagValue(long val) {
+    public static Serializable<BanyandbModel.TagValue> longTagValue(Long val) {
+        if (val == null) {
+            return nullTagValue();
+        }
         return new LongTagValue(val);
     }
 
@@ -176,6 +161,9 @@ public abstract class Value<T> {
      * @return Anonymous tag with string array payload
      */
     public static Serializable<BanyandbModel.TagValue> stringArrayTagValue(List<String> val) {
+        if (val == null) {
+            return nullTagValue();
+        }
         return new StringArrayTagValue(val);
     }
 
@@ -186,6 +174,9 @@ public abstract class Value<T> {
      * @return Anonymous tag with binary payload
      */
     public static Serializable<BanyandbModel.TagValue> binaryTagValue(byte[] bytes) {
+        if (bytes == null) {
+            return nullTagValue();
+        }
         return new BinaryTagValue(ByteString.copyFrom(bytes));
     }
 
@@ -196,6 +187,9 @@ public abstract class Value<T> {
      * @return Anonymous tag with numeric array payload
      */
     public static Serializable<BanyandbModel.TagValue> longArrayTag(List<Long> val) {
+        if (val == null) {
+            return nullTagValue();
+        }
         return new LongArrayTagValue(val);
     }
 
