@@ -81,7 +81,7 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
                         .addTagSpec(TagFamilySpec.TagSpec.newIntTag("start_time"))
                         .addTagSpec(TagFamilySpec.TagSpec.newIntTag("duration"))
                         .build())
-                .addIndex(IndexRule.create("trace_id", IndexRule.IndexType.INVERTED, IndexRule.IndexLocation.GLOBAL))
+                .addIndex(IndexRule.create("trace_id", IndexRule.IndexType.INVERTED))
                 .build();
         this.client.define(expectedStream);
     }
@@ -92,7 +92,7 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
 
         Instant end = Instant.now();
         Instant begin = end.minus(15, ChronoUnit.MINUTES);
-        StreamQuery query = new StreamQuery("default", "sw",
+        StreamQuery query = new StreamQuery(Lists.newArrayList("default"), "sw",
                 new TimestampRange(begin.toEpochMilli(), end.toEpochMilli()),
                 ImmutableSet.of("state", "start_time", "duration", "trace_id"));
         // search for all states
@@ -104,8 +104,8 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
 
         final BanyandbStream.QueryRequest request = requestCaptor.getValue();
         // assert metadata
-        Assert.assertEquals("sw", request.getMetadata().getName());
-        Assert.assertEquals("default", request.getMetadata().getGroup());
+        Assert.assertEquals("sw", request.getName());
+        Assert.assertEquals("default", request.getGroups(0));
         // assert timeRange, both seconds and the nanos
         Assert.assertEquals(begin.toEpochMilli() / 1000, request.getTimeRange().getBegin().getSeconds());
         Assert.assertEquals(TimeUnit.MILLISECONDS.toNanos(begin.toEpochMilli() % 1000), request.getTimeRange().getBegin().getNanos());
@@ -139,7 +139,7 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
         long minDuration = 10;
         long maxDuration = 100;
 
-        StreamQuery query = new StreamQuery("default", "sw",
+        StreamQuery query = new StreamQuery(Lists.newArrayList("default"), "sw",
                 new TimestampRange(begin.toEpochMilli(), end.toEpochMilli()),
                 ImmutableSet.of("state", "start_time", "duration", "trace_id"));
         // search for the successful states
@@ -149,6 +149,7 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
                 .and(PairQueryCondition.StringQueryCondition.match("endpoint_id", endpointId))
                 .and(PairQueryCondition.LongQueryCondition.ge("duration", minDuration))
                 .and(PairQueryCondition.LongQueryCondition.le("duration", maxDuration))
+                .and(PairQueryCondition.StringArrayQueryCondition.in("trace_id", Lists.newArrayList("aaa", "bbb")))
                 .setOrderBy(new StreamQuery.OrderBy("start_time", AbstractQuery.Sort.ASC));
 
         client.query(query);
@@ -156,8 +157,8 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
         verify(streamQueryServiceImpl).query(requestCaptor.capture(), ArgumentMatchers.any());
         final BanyandbStream.QueryRequest request = requestCaptor.getValue();
         // assert metadata
-        Assert.assertEquals("sw", request.getMetadata().getName());
-        Assert.assertEquals("default", request.getMetadata().getGroup());
+        Assert.assertEquals("sw", request.getName());
+        Assert.assertEquals("default", request.getGroups(0));
         // assert timeRange
         Assert.assertEquals(begin.getEpochSecond(), request.getTimeRange().getBegin().getSeconds());
         Assert.assertEquals(end.getEpochSecond(), request.getTimeRange().getEnd().getSeconds());
@@ -166,11 +167,12 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
                 "  op: LOGICAL_OP_AND\n" +
                 "  left {\n" +
                 "    condition {\n" +
-                "      name: \"duration\"\n" +
-                "      op: BINARY_OP_LE\n" +
+                "      name: \"trace_id\"\n" +
+                "      op: BINARY_OP_IN\n" +
                 "      value {\n" +
-                "        int {\n" +
-                "          value: 100\n" +
+                "        str_array {\n" +
+                "          value: \"aaa\"\n" +
+                "          value: \"bbb\"\n" +
                 "        }\n" +
                 "      }\n" +
                 "    }\n" +
@@ -181,10 +183,10 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
                 "      left {\n" +
                 "        condition {\n" +
                 "          name: \"duration\"\n" +
-                "          op: BINARY_OP_GE\n" +
+                "          op: BINARY_OP_LE\n" +
                 "          value {\n" +
                 "            int {\n" +
-                "              value: 10\n" +
+                "              value: 100\n" +
                 "            }\n" +
                 "          }\n" +
                 "        }\n" +
@@ -194,11 +196,11 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
                 "          op: LOGICAL_OP_AND\n" +
                 "          left {\n" +
                 "            condition {\n" +
-                "              name: \"endpoint_id\"\n" +
-                "              op: BINARY_OP_MATCH\n" +
+                "              name: \"duration\"\n" +
+                "              op: BINARY_OP_GE\n" +
                 "              value {\n" +
-                "                str {\n" +
-                "                  value: \"/check_0\"\n" +
+                "                int {\n" +
+                "                  value: 10\n" +
                 "                }\n" +
                 "              }\n" +
                 "            }\n" +
@@ -208,11 +210,11 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
                 "              op: LOGICAL_OP_AND\n" +
                 "              left {\n" +
                 "                condition {\n" +
-                "                  name: \"service_instance_id\"\n" +
-                "                  op: BINARY_OP_EQ\n" +
+                "                  name: \"endpoint_id\"\n" +
+                "                  op: BINARY_OP_MATCH\n" +
                 "                  value {\n" +
                 "                    str {\n" +
-                "                      value: \"service_id_b_1\"\n" +
+                "                      value: \"/check_0\"\n" +
                 "                    }\n" +
                 "                  }\n" +
                 "                }\n" +
@@ -222,11 +224,11 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
                 "                  op: LOGICAL_OP_AND\n" +
                 "                  left {\n" +
                 "                    condition {\n" +
-                "                      name: \"service_id\"\n" +
+                "                      name: \"service_instance_id\"\n" +
                 "                      op: BINARY_OP_EQ\n" +
                 "                      value {\n" +
                 "                        str {\n" +
-                "                          value: \"service_id_b\"\n" +
+                "                          value: \"service_id_b_1\"\n" +
                 "                        }\n" +
                 "                      }\n" +
                 "                    }\n" +
@@ -236,11 +238,27 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
                 "                      op: LOGICAL_OP_AND\n" +
                 "                      left {\n" +
                 "                        condition {\n" +
-                "                          name: \"state\"\n" +
+                "                          name: \"service_id\"\n" +
                 "                          op: BINARY_OP_EQ\n" +
                 "                          value {\n" +
-                "                            int {\n" +
-                "                              value: 1\n" +
+                "                            str {\n" +
+                "                              value: \"service_id_b\"\n" +
+                "                            }\n" +
+                "                          }\n" +
+                "                        }\n" +
+                "                      }\n" +
+                "                      right {\n" +
+                "                        le {\n" +
+                "                          op: LOGICAL_OP_AND\n" +
+                "                          left {\n" +
+                "                            condition {\n" +
+                "                              name: \"state\"\n" +
+                "                              op: BINARY_OP_EQ\n" +
+                "                              value {\n" +
+                "                                int {\n" +
+                "                                  value: 1\n" +
+                "                                }\n" +
+                "                              }\n" +
                 "                            }\n" +
                 "                          }\n" +
                 "                        }\n" +
@@ -268,7 +286,7 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
         ArgumentCaptor<BanyandbStream.QueryRequest> requestCaptor = ArgumentCaptor.forClass(BanyandbStream.QueryRequest.class);
         String traceId = "1111.222.333";
 
-        StreamQuery query = new StreamQuery("default", "sw", ImmutableSet.of("state", "start_time", "duration", "trace_id", "data_binary"));
+        StreamQuery query = new StreamQuery(Lists.newArrayList("default"), "sw", ImmutableSet.of("state", "start_time", "duration", "trace_id", "data_binary"));
         query.and(PairQueryCondition.StringQueryCondition.eq("trace_id", traceId));
 
         client.query(query);
@@ -276,8 +294,8 @@ public class BanyanDBClientStreamQueryTest extends AbstractBanyanDBClientTest {
         verify(streamQueryServiceImpl).query(requestCaptor.capture(), ArgumentMatchers.any());
         final BanyandbStream.QueryRequest request = requestCaptor.getValue();
         // assert metadata
-        Assert.assertEquals("sw", request.getMetadata().getName());
-        Assert.assertEquals("default", request.getMetadata().getGroup());
+        Assert.assertEquals("sw", request.getName());
+        Assert.assertEquals("default", request.getGroups(0));
         Assert.assertEquals("condition {\n" +
                 "  name: \"trace_id\"\n" +
                 "  op: BINARY_OP_EQ\n" +
